import * as React from 'react';
import { Table, Button, Modal, Input, Header, Container, InputOnChangeData, ButtonProps } from 'semantic-ui-react';
import { TargetDetail } from './TargetDetail';
import Target from '@overflow/target/api/model/Target';
import Probe from '@overflow/probe/api/model/Probe';
import { ListContainer } from '@overflow/commons/react/component/ListContainer';
import { Discovery } from '../../../discovery/react/components/Discovery';

export interface StateProps {

}

export interface DispatchProps {
  onReadAllByProbe(probe: Probe): void;
  onTargetSelection(id: string): void;
}

export type Props = StateProps & DispatchProps;

export interface State {
  selected: Target;
  openAddTarget: boolean;
  list: Target[];
}

export class TargetList extends React.Component<Props, State> {

  private data: any;
  constructor(props: Props, context: State) {
    super(props, context);
    this.state = {
      selected: null,
      openAddTarget: false,
      list: null,
    };
  }

  public componentWillMount(): void {
    this.data = [
      {
        'id': '1',
        'createDate': '2017-01-01',
        'displayName': 'Oracle',
        'description': '',
        'sensorCount': 'todo.',
      },
      {
        'id': '2',
        'createDate': '2017-01-01',
        'displayName': 'MySQL',
        'description': '',
        'sensorCount': 'todo.',
      },
      {
        'id': '3',
        'createDate': '2017-01-01',
        'displayName': '192.168.1.105',
        'description': '',
        'sensorCount': 'todo.',
      },
    ];

    this.setState({ list: this.data });
  }

  public handleSelect(selectedTarget: any): void {

    this.setState({
      selected: selectedTarget,
    });

    this.props.onTargetSelection(selectedTarget.id);
  }


  public handleAddTarget(event: React.MouseEvent<HTMLButtonElement>, data: ButtonProps): void {
    this.setState({
      openAddTarget: true,
    });
  }

  public handleSearch(result: Target[]): void {
    this.setState({
      list: result,
    });
  }

  public handleFilter(filterStr: string): void {
    if (filterStr === null) {
      this.setState({
        list: this.data,
      });
      return;
    }
    let founds = new Array();
    for (let probe of this.data) {
      if (probe.metaProbeStatus.name.indexOf(filterStr) !== -1) {
        founds.push(probe);
      }
    }
    this.setState({
      list: founds,
    });
  }

  public render(): JSX.Element {
    let targetList =
      <Container fluid>
        {/*search bar  */}
        <Button content='Discovery' icon='search' labelPosition='left' floated='right' positive onClick={this.handleAddTarget.bind(this)} />
        <br /><br />
        <Table celled selectable striped>
          <Table.Header>
            <Table.Row>
              <Table.HeaderCell textAlign={'center'}>No</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>Name</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'} collapsing>Sensor Count</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>Created at</Table.HeaderCell>
            </Table.Row>
          </Table.Header>

          <Table.Body>
            {this.state.list.map((target: any, index: number) => (
              <Table.Row key={index} onClick={this.handleSelect.bind(this, target)}>
                <Table.Cell textAlign={'center'}>{index + 1}</Table.Cell>
                <Table.Cell textAlign={'center'}>{target.displayName}</Table.Cell>
                <Table.Cell>{target.sensorCount}</Table.Cell>
                <Table.Cell>{target.createDate}</Table.Cell>
              </Table.Row>
            ))}
          </Table.Body>
        </Table>
        <Modal
          open={this.state.openAddTarget}
        >
          {/*<Modal.Header>*/}
          {/*Adding a Target*/}
          {/*</Modal.Header>*/}
          <Modal.Content>
            <Discovery />
          </Modal.Content>
          <Modal.Actions>
            <Button onClick={() => this.setState({ openAddTarget: false })}>Cancel</Button>
            <Button primary >Done</Button>
          </Modal.Actions>
        </Modal>
      </Container>;
    return (
      <ListContainer
        contents={targetList}
        data={this.data}
        onSearch={this.handleSearch.bind(this)}
        filter={null}
      />
    );
  }

  private handleSelectedTarget = (target: Target): void => {
    console.log('handleSelectedTarget ');
    this.setState({ selected: target });

    this.props.onTargetSelection(String(target.id));
  }
}

